@@ -3,7 +3,7 @@
 # ||                                                                        ||
 # || CipUX RPC Server Class                                                 ||
 # ||                                                                        ||
-# || Copyright (C) 2007 - 2009 by Christian Kuelker                         ||
+# || Copyright (C) 2007 - 2010 by Christian Kuelker                         ||
 # ||                                                                        ||
 # || License: GNU GPL - GNU general public license - version 2              ||
 # ||          or (at your opinion) any later version.                       ||
@@ -74,9 +74,10 @@ use base qw(CipUX::RPC);
     # - rpc_info
     # - rpc_intern
 
-    use version; our $VERSION = qv('3.4.0.8');
+    use version; our $VERSION = qv('3.4.0.9');
     use re 'taint';    # Keep data captured by parens tainted
     delete @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};    # Make %ENV safe
+    use vars qw($cache_dir);
 
     # +======================================================================+
     # || CONST                                                              ||
@@ -134,14 +135,14 @@ use base qw(CipUX::RPC);
         # | API
         my ( $self, $ident, $arg_r ) = @_;
 
-        my $cache_dir
+        $cache_dir
             = exists $arg_r->{cache_dir}
             ? $self->l( $arg_r->{cache_dir} )
             : $EMPTY_STRING;
 
         # +------------------------------------------------------------------+
         # | main
-        $cipux_task         = CipUX::Task->new( { cache_dir => $cache_dir } );
+        my $cipux_task = CipUX::Task->new( { cache_dir => $cache_dir } );
         $cipux_task_list_ar = $cipux_task->list_task();
         $rpc                = CipUX::RPC->new( { cache_dir => $cache_dir } );
         $rbac               = CipUX::RBAC::Simple->new();
@@ -717,8 +718,9 @@ use base qw(CipUX::RPC);
         # | prepare
         my $logger = get_logger(__PACKAGE__);
 
-        my %task     = ();
-        my $return_r = $cipux_task->task(
+        my %task       = ();
+        my $cipux_task = CipUX::Task->new( { cache_dir => $cache_dir } );
+        my $return_r   = $cipux_task->task(
             {
                 script  => __PACKAGE__,
                 task    => 'cipux_task_list_tasks',
@@ -794,8 +796,9 @@ use base qw(CipUX::RPC);
         # | prepare
         my $logger = get_logger(__PACKAGE__);
 
-        my %cat      = ();
-        my $return_r = $cipux_task->task(
+        my %cat        = ();
+        my $cipux_task = CipUX::Task->new( { cache_dir => $cache_dir } );
+        my $return_r   = $cipux_task->task(
             {
                 script  => __PACKAGE__,
                 task    => 'cipux_task_list_cat_modules',
@@ -1408,7 +1411,7 @@ use base qw(CipUX::RPC);
             return $answer_hr;
         }
         else {
-            my $msg = 'WARN password is valid NOT for login login ';
+            my $msg = 'WARN password is valid NOT for login ';
             $logger->debug( $msg . q{: }, $login );
 
           # +----------------------------------------------------------------+
@@ -1794,6 +1797,7 @@ use base qw(CipUX::RPC);
 
         }
 
+        my $cipux_task = CipUX::Task->new( { cache_dir => $cache_dir } );
         my $return_r = $cipux_task->task(
             {
                 script  => $SCRIPT,
@@ -2155,7 +2159,7 @@ CipUX::RPC::Server - RPC server class for CipUX
 
 =head1 VERSION
 
-version 3.4.0.8
+version 3.4.0.9
 
 =head1 SYNOPSIS
 
@@ -2466,7 +2470,7 @@ Christian Kuelker  E<lt>christian.kuelker@cipworx.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2007 - 2009 by Christian Kuelker
+Copyright (C) 2007 - 2010 by Christian Kuelker
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
